@@ -2,6 +2,7 @@ from enum import Enum
 from vint.ast.plugin.abstract_ast_plugin import AbstractASTPlugin
 from vint.ast.traversing import traverse
 from vint.ast.node_type import NodeType
+from vint.ast.plugin.builtin_identifiers import BuiltinIdentifierMap
 
 
 class DeclarationScope(Enum):
@@ -23,8 +24,8 @@ class ScopeType(Enum):
 class ScopePlugin(AbstractASTPlugin):
     SCOPE_TREE_KEY = 'vint_scope_tree'
     SCOPE_KEY = 'vint_scope'
-    DEFINITION_IDENTIFIER_FLAG_KEY = 'vint_scope_identifier_is_definition'
-
+    DEFINITION_IDENTIFIER_FLAG_KEY = 'VINT:is_definition_identifier'
+    BUILTIN_IDENTIFIER_FLAG_KEY = 'VINT:is_builtin_identifier'
 
     prefix_to_declaration_scope_map = {
         'g:': DeclarationScope.GLOBAL,
@@ -47,8 +48,8 @@ class ScopePlugin(AbstractASTPlugin):
             NodeType.TOPLEVEL: self._handle_enter_toplevel,
             NodeType.FUNCTION: self._handle_enter_function,
             NodeType.IDENTIFIER: self._handle_enter_identifier,
-            NodeType.LET: self._handle_enter_node_have_left_identifier,
-            NodeType.FOR: self._handle_enter_node_have_left_identifier,
+            NodeType.LET: self._handle_enter_destructuring_assignment_node,
+            NodeType.FOR: self._handle_enter_destructuring_assignment_node,
         }
 
         self.node_type_to_on_leave_handler_map = {
@@ -130,6 +131,28 @@ class ScopePlugin(AbstractASTPlugin):
         identifier[ScopePlugin.DEFINITION_IDENTIFIER_FLAG_KEY] = True
 
 
+    def _handle_enter_destructuring_assignment_node(self, node):
+        # See:
+        #   :help :for
+        #   :help :let
+        is_destructuring_assignment = len(node['list']) > 0
+
+        if is_destructuring_assignment:
+            self._handle_enter_node_have_list(node)
+        else:
+            self._handle_enter_node_have_left_identifier(node)
+
+
+    def _handle_enter_node_have_list(self, node):
+        list_nodes = node['list']
+
+        for elem_node in list_nodes:
+            identifier_name = ScopePlugin.get_normalized_identifier(elem_node)
+
+            self._mark_difinition_identifier(elem_node)
+            self._handle_new_variable(identifier_name)
+
+
     def _handle_enter_node_have_left_identifier(self, node):
         left_node = node['left']
         identifier_name = ScopePlugin.get_normalized_identifier(left_node)
@@ -146,12 +169,15 @@ class ScopePlugin(AbstractASTPlugin):
         self._handle_enter_node_have_left_identifier(node)
 
 
-    def _handle_enter_identifier(self, node):
-        node[ScopePlugin.SCOPE_KEY] = self.current_scope
+    def _handle_enter_identifier(self, identifier_node):
+        identifier_node[ScopePlugin.SCOPE_KEY] = self.current_scope
 
         # Make all idenifiers to contain DEFINITION_IDENTIFIER_FLAG.
-        if ScopePlugin.DEFINITION_IDENTIFIER_FLAG_KEY not in node:
-            node[ScopePlugin.DEFINITION_IDENTIFIER_FLAG_KEY] = False
+        if ScopePlugin.DEFINITION_IDENTIFIER_FLAG_KEY not in identifier_node:
+            identifier_node[ScopePlugin.DEFINITION_IDENTIFIER_FLAG_KEY] = False
+
+        identifier = identifier_node['value']
+        identifier_node[ScopePlugin.BUILTIN_IDENTIFIER_FLAG_KEY] = identifier in BuiltinIdentifierMap
 
 
     def _handle_leave(self, node):
